==> centreon-web-24.10.16.tar.gz: centreon-web-24.10.16/tests/e2e/features/Authentication/OpenID-connect/common.ts <==
import { ActionClapi } from '../../../commons';

interface OidcConfigValues {
  authEndpoint: string;
  baseUrl: string;
  // biome-ignore lint/style/useNamingConvention: <explanation>
  clientID: string;
  clientSecret: string;
  introspectionTokenEndpoint: string;
  loginAttrPath: string;
  scopes: string;
  tokenEndpoint: string;
}

const getOidcConfigValues = ({
  providerAddress = 'sso-proxy',
  providerPort = 8080
}): OidcConfigValues => ({
  authEndpoint: '/auth',
  baseUrl: `http://${providerAddress}:${providerPort}/realms/Centreon_SSO/protocol/openid-connect`,
  // biome-ignore lint/style/useNamingConvention: <explanation>
  clientID: 'centreon-oidc-frontend',
  clientSecret: 'IKbUBottl5eoyhf0I5Io2nuDsTA85D50',
  introspectionTokenEndpoint: '/token/introspect',
  loginAttrPath: 'preferred_username',
  scopes: 'openid',
  tokenEndpoint: '/token'
});

const initializeOidcUserAndGetLoginPage = (): Cypress.Chainable => {
  return cy
    .fixture('resources/clapi/contact-OIDC/OIDC-authentication-user.json')
    .then((fixture: Array<ActionClapi>) => {
      fixture.forEach((action) =>
        cy.executeActionViaClapi({ bodyContent: action })
      );
    });
};

const removeContact = (): Cypress.Chainable => {
  return cy.setUserTokenApiV1().then(() => {
    cy.executeActionViaClapi({
      bodyContent: {
        action: 'DEL',
        object: 'CONTACT',
        values: 'oidc'
      }
    });
  });
};

const configureOpenIdConnect = (): Cypress.Chainable => {
  cy.contains('Enable OpenID Connect authentication').should('be.visible');

  return cy.getContainerIpAddress('openid').then((containerIpAddress) => {
    const oidcConfigValues = getOidcConfigValues({
      providerAddress: containerIpAddress,
      providerPort: 8080
    });

    // Identity provider section
    cy.getByLabel({ label: 'Identity provider', tag: 'div' }).click();
    cy.getByLabel({ label: 'Base URL', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.baseUrl}`);
    cy.getByLabel({ label: 'Authorization endpoint', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.authEndpoint}`);
    cy.getByLabel({ label: 'Token endpoint', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.tokenEndpoint}`);
    cy.getByLabel({ label: 'Client ID', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.clientID}`);
    cy.getByLabel({ label: 'Client secret', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.clientSecret}`);
    cy.getByLabel({ label: 'Scopes', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.scopes}{enter}`);
    cy.getByLabel({ label: 'Login attribute path', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.loginAttrPath}`);
    cy.getByLabel({ label: 'Introspection token endpoint', tag: 'input' })
      .should('be.visible')
      .type(
        `{selectall}{backspace}${oidcConfigValues.introspectionTokenEndpoint}`
      );
    cy.getByLabel({
      label: 'Use basic authentication for token endpoint authentication',
      tag: 'input'
    }).uncheck();

    return cy
      .getByLabel({ label: 'Disable verify peer', tag: 'input' })
      .check();
  });
};

const saveOpenIdFormIfEnabled = () => {
  return cy.getByLabel({ label: 'save button', tag: 'button' }).then(($btn) => {
    if ($btn.is(':disabled')) {
      return;
    }
    cy.wrap($btn).click();

    return cy
      .wait('@updateOIDCProvider')
      .its('response.statusCode')
      .should('eq', 204);
  });
};

export {
  removeContact,
  initializeOidcUserAndGetLoginPage,
  configureOpenIdConnect,
  saveOpenIdFormIfEnabled
};

==> centreon-web-25.10.0.tar.gz: centreon-web-25.10.0/tests/e2e/features/Authentication/OpenID-connect/common.ts <==
import { ActionClapi } from '../../../commons';

interface OidcConfigValues {
  authEndpoint: string;
  baseUrl: string;
  clientId: string;
  clientSecret: string;
  introspectionTokenEndpoint: string;
  loginAttrPath: string;
  scopes: string;
  tokenEndpoint: string;
}

const getOidcConfigValues = ({
  providerAddress = 'sso-proxy',
  providerPort = 8080
}): OidcConfigValues => ({
  authEndpoint: '/auth',
  baseUrl: `http://${providerAddress}:${providerPort}/realms/Centreon_SSO/protocol/openid-connect`,
  clientId: 'centreon-oidc-frontend',
  clientSecret: 'IKbUBottl5eoyhf0I5Io2nuDsTA85D50',
  introspectionTokenEndpoint: '/token/introspect',
  loginAttrPath: 'preferred_username',
  scopes: 'openid',
  tokenEndpoint: '/token'
});

const initializeOidcUserAndGetLoginPage = (): Cypress.Chainable => {
  return cy
    .fixture('resources/clapi/contact-OIDC/OIDC-authentication-user.json')
    .then((fixture: Array<ActionClapi>) => {
      fixture.forEach((action) =>
        cy.executeActionViaClapi({ bodyContent: action })
      );
    });
};

const removeContact = (): Cypress.Chainable => {
  return cy.setUserTokenApiV1().then(() => {
    cy.executeActionViaClapi({
      bodyContent: {
        action: 'DEL',
        object: 'CONTACT',
        values: 'oidc'
      }
    });
  });
};

const configureOpenIdConnect = (): Cypress.Chainable => {
  cy.contains('Enable OpenID Connect authentication').should('be.visible');

  return cy.getContainerIpAddress('openid').then((containerIpAddress) => {
    const oidcConfigValues = getOidcConfigValues({
      providerAddress: containerIpAddress,
      providerPort: 8080
    });

    // Identity provider section
    cy.getByLabel({ label: 'Identity provider', tag: 'div' }).click();
    cy.getByLabel({ label: 'Base URL', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.baseUrl}`);
    cy.getByLabel({ label: 'Authorization endpoint', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.authEndpoint}`);
    cy.getByLabel({ label: 'Token endpoint', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.tokenEndpoint}`);
    cy.getByLabel({ label: 'Client ID', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.clientId}`);
    cy.getByLabel({ label: 'Client secret', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.clientSecret}`);
    cy.getByLabel({ label: 'Scopes', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.scopes}{enter}`);
    cy.getByLabel({ label: 'Login attribute path', tag: 'input' })
      .should('be.visible')
      .type(`{selectall}{backspace}${oidcConfigValues.loginAttrPath}`);
    cy.getByLabel({ label: 'Introspection token endpoint', tag: 'input' })
      .should('be.visible')
      .type(
        `{selectall}{backspace}${oidcConfigValues.introspectionTokenEndpoint}`
      );
    cy.getByLabel({
      label: 'Use basic authentication for token endpoint authentication',
      tag: 'input'
    }).uncheck();

    return cy
      .getByLabel({ label: 'Disable verify peer', tag: 'input' })
      .check();
  });
};

const saveOpenIdFormIfEnabled = () => {
  return cy.getByLabel({ label: 'save button', tag: 'button' }).then(($btn) => {
    if ($btn.is(':disabled')) {
      return;
    }
    cy.wrap($btn).click();

    return cy
      .wait('@updateOIDCProvider')
      .its('response.statusCode')
      .should('eq', 204);
  });
};

export {
  removeContact,
  initializeOidcUserAndGetLoginPage,
  configureOpenIdConnect,
  saveOpenIdFormIfEnabled
};
